#include "stdafx.h"

#include "grid.h"
#include "ff3se.h"
#include "resource.h"
#include "options.h"

GridDialog gridDialog;

/*************************************/
//Changes the grid setting based on which button is checked
void GridDialog::changeGrid(void)
{
	int i;

	for (i = 0; i < 3; i++)
	{
		if (SendDlgItemMessage(hGrid, IDC_GRID_NOSHOW + i, BM_GETCHECK, 0, 0))
			tempGrid = i;
	}
}

/*************************************/
//Handles the Up Down control to alter the minimum magnification setting
void GridDialog::handleUpDown(void)
{
	tempMinMag = (BYTE)SendDlgItemMessage(hGrid, IDC_GRID_UPDOWN, UDM_GETPOS, 0, 0);
	paint();
}

//Display the Grid Dialog
//Initializes controls to initial settings
/*************************************/
void GridDialog::show(void)
{
	RECT r;

	hGrid = CreateDialog(hInst, MAKEINTRESOURCE(IDD_GRID), hWnd, ::gridProc);
	hDlg = hGrid;

	GetWindowRect(hWnd, &r);
	SetWindowPos(hGrid, HWND_NOTOPMOST, r.left + 200, r.top + 200, 0, 0, SWP_NOSIZE | SWP_SHOWWINDOW);

	EnableWindow(hWnd, false);

	tempGrid = options.getGrid();
	tempMinMag = options.getGridMinMag();

	SendDlgItemMessage(hGrid, IDC_GRID_UPDOWN, UDM_SETRANGE, 0, (LPARAM)MAKELONG((short)20, (short)2));
	SendDlgItemMessage(hGrid, IDC_GRID_UPDOWN, UDM_SETPOS, 0, (LPARAM)MAKELONG((short)tempMinMag, 0));
}

/*************************************/
//Called when WM_PAINT is received
//Updates the minimum magnification text control
void GridDialog::paint(void)
{
	char minMag[10];
	HWND hCtrl;

	sprintf(minMag, "%d", tempMinMag);

	hCtrl = GetDlgItem(hGrid, IDC_GRID_MAG);
	SetWindowText(hCtrl, minMag);

	SendDlgItemMessage(hGrid, IDC_GRID_NOSHOW + tempGrid, BM_SETCHECK, BST_CHECKED, 0);
}

/*************************************/
BOOL GridDialog::gridProc(HWND hdlg, UINT message, WPARAM wParam, LPARAM lParam)
{
	switch (message)
	{
	case WM_CLOSE:
		EnableWindow(hWnd, true);
		DestroyWindow(hGrid);
		break;
	case WM_COMMAND:
		switch (LOWORD(wParam))
		{
		case IDC_GRID_OK:
			options.setGrid(tempGrid, tempMinMag);
			EnableWindow(hWnd, true);
			DestroyWindow(hGrid);
			break;
		case IDC_GRID_CANCEL:
			EnableWindow(hWnd, true);
			DestroyWindow(hGrid);
			break;
		case IDC_GRID_NOSHOW:
		case IDC_GRID_SHOWPIXEL:
		case IDC_GRID_SHOWTILE:
			changeGrid();
			break;
		}
		break;
	case WM_NOTIFY:
		switch (LOWORD(wParam))
		{
		case IDC_GRID_UPDOWN:
			handleUpDown();
			break;
		}
		break;
	case WM_PAINT:
		paint();
		break;
	}

	return 0;
}

/*************************************/
BOOL CALLBACK gridProc(HWND hdlg, UINT message, WPARAM wParam, LPARAM lParam)
{
	return gridDialog.gridProc(hdlg, message, wParam, lParam);
}
